Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(12413)

Unified Diff: components/signin/ios/browser/profile_oauth2_token_service_ios.mm

Issue 1143323005: Refactor AO2TS to make it easier to componentize. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: address roger's comments Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/signin/ios/browser/profile_oauth2_token_service_ios.mm
diff --git a/components/signin/ios/browser/profile_oauth2_token_service_ios.mm b/components/signin/ios/browser/profile_oauth2_token_service_ios.mm
index 2eb3cff42429ff2564df047782c82c5e57351f19..8931fae477a6573dfcfb40a095cbca08f530069e 100644
--- a/components/signin/ios/browser/profile_oauth2_token_service_ios.mm
+++ b/components/signin/ios/browser/profile_oauth2_token_service_ios.mm
@@ -309,19 +309,17 @@ ProfileOAuth2TokenServiceIOS::CreateAccessTokenFetcher(
return new SSOAccessTokenFetcher(consumer, GetProvider(), account_id);
}
-void ProfileOAuth2TokenServiceIOS::InvalidateOAuth2Token(
+void ProfileOAuth2TokenServiceIOS::InvalidateAccessToken(
const std::string& account_id,
const std::string& client_id,
const ScopeSet& scopes,
const std::string& access_token) {
DCHECK(thread_checker_.CalledOnValidThread());
// Call |ProfileOAuth2TokenService::InvalidateOAuth2Token| to clear the
// cached access token.
- ProfileOAuth2TokenService::InvalidateOAuth2Token(account_id,
- client_id,
- scopes,
- access_token);
+ ProfileOAuth2TokenService::InvalidateAccessToken(account_id, client_id,
+ scopes, access_token);
// There is no need to inform the authentication library that the access
// token is invalid as it never caches the token.
@@ -309,19 +309,17 @@ ProfileOAuth2TokenServiceIOS::CreateAccessTokenFetcher(
const std::string& access_token) {
DCHECK(thread_checker_.CalledOnValidThread());
- // Call |ProfileOAuth2TokenService::InvalidateOAuth2Token| to clear the
+ // Call |ProfileOAuth2TokenService::InvalidateAccessToken| to clear the
// cached access token.

Powered by Google App Engine
This is Rietveld 408576698